@@ -257,10 +257,14 @@ int main(int argc, char **argv)
 	if (argc == 0)		/* no frequency, on|off, or +|- given */
 		help(progname);
 
-	if (argc == 2)
-		tunevol = atoi(argv[1]);
-	else
-		tunevol = defaultvol;
+	if (argc == 2) {
+                int percent = atoi(argv[1]);
+                tunevol = (percent <= 0 ? 0
+                           : percent >= 100 ? 65536
+                           : percent * 655.36);
+        } else {
+                tunevol = defaultvol; 
+        }
 
 	if (!dev)
 		dev = DEFAULT_DEVICE;
